@@ -2,77 +2,6 @@
 #include "triplet_to_col.h"
 #include <R_ext/Lapack.h>
 
-SEXP
-    Matrix_DSym,
-    Matrix_DIsqrtSym,
-    Matrix_DimSym,
-    Matrix_GpSym,
-    Matrix_LSym,
-    Matrix_LiSym,
-    Matrix_LinvSym,
-    Matrix_LpSym,
-    Matrix_LxSym,
-    Matrix_OmegaSym,
-    Matrix_ParentSym,
-    Matrix_RXXSym,
-    Matrix_RZXSym,
-    Matrix_XtXSym,
-    Matrix_ZtXSym,
-    Matrix_ZZxSym,
-    Matrix_bVarSym,
-    Matrix_cnamesSym,
-    Matrix_devianceSym,
-    Matrix_devCompSym,
-    Matrix_diagSym,
-    Matrix_iSym,
-    Matrix_ipermSym,
-    Matrix_jSym,
-    Matrix_matSym,
-    Matrix_ncSym,
-    Matrix_pSym,
-    Matrix_permSym,
-    Matrix_statusSym,
-    Matrix_uploSym,
-    Matrix_xSym,
-    Matrix_zSym;
-
-SEXP Matrix_init(void)
-{
-    Matrix_DSym = install("D");
-    Matrix_DIsqrtSym = install("DIsqrt");
-    Matrix_DimSym = install("Dim");
-    Matrix_GpSym = install("Gp");
-    Matrix_LSym = install("L");
-    Matrix_LiSym = install("Li");
-    Matrix_LinvSym = install("Linv");
-    Matrix_LpSym = install("Lp");
-    Matrix_LxSym = install("Lx");
-    Matrix_OmegaSym = install("Omega");
-    Matrix_ParentSym = install("Parent");
-    Matrix_RXXSym = install("RXX");
-    Matrix_RZXSym = install("RZX");
-    Matrix_XtXSym = install("XtX");
-    Matrix_ZtXSym = install("ZtX");
-    Matrix_ZZxSym = install("ZZx");
-    Matrix_bVarSym = install("bVar");
-    Matrix_cnamesSym = install("cnames");
-    Matrix_devianceSym = install("deviance");
-    Matrix_devCompSym = install("devComp");
-    Matrix_diagSym = install("diag");
-    Matrix_iSym = install("i");
-    Matrix_ipermSym = install("iperm");
-    Matrix_jSym = install("j");
-    Matrix_matSym = install("mat");
-    Matrix_ncSym = install("nc");
-    Matrix_pSym = install("p");
-    Matrix_permSym = install("perm");
-    Matrix_statusSym = install("status");
-    Matrix_uploSym = install("uplo");
-    Matrix_xSym = install("x");
-    Matrix_zSym = install("z");
-    return R_NilValue;
-}
-
 char norm_type(char *typstr)
 {
     char typup;
