@@ -3,14 +3,12 @@
 
 #include "Mutils.h"
 #include "triplet_to_col.h"
+#include "cscBlocked.h"
 #include <R_ext/Lapack.h>
 #include <R_ext/Constants.h>
 
-#ifndef R_INLINE
-#define R_INLINE
-#endif
-
 SEXP lmeRep_validate(SEXP x);
+SEXP lmeRep_crosstab(SEXP facs);
 SEXP lmeRep_create(SEXP facs, SEXP ncv);
 SEXP lmeRep_update_mm(SEXP x, SEXP facs, SEXP mmats);
 SEXP lmeRep_initial(SEXP x);
@@ -23,6 +21,6 @@ SEXP lmeRep_fixef(SEXP x);
 SEXP lmeRep_ranef(SEXP x);
 SEXP lmeRep_ECMEsteps(SEXP x, SEXP nsteps, SEXP REMLp, SEXP Verbp);
 SEXP lmeRep_gradient(SEXP x, SEXP REMLp, SEXP Uncp);
-
+SEXP lmeRep_variances(SEXP x);
 
 #endif
